You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by jm...@apache.org on 2014/04/26 09:31:07 UTC

[1/4] git commit: [flex-sdk] [refs/heads/release4.12.0] - fix few minor layout issues and updated to mention FP/AIR 13 support

Repository: flex-sdk
Updated Branches:
  refs/heads/release4.12.0 f3bcf0142 -> d83446c76


fix few minor layout issues and updated to mention FP/AIR 13 support


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/52043a78
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/52043a78
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/52043a78

Branch: refs/heads/release4.12.0
Commit: 52043a783334d225c353026b3a77e5ca5bd4f261
Parents: f3bcf01
Author: Justin Mclean <jm...@apache.org>
Authored: Sat Apr 26 17:25:44 2014 +1000
Committer: Justin Mclean <jm...@apache.org>
Committed: Sat Apr 26 17:25:44 2014 +1000

----------------------------------------------------------------------
 README | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/52043a78/README
----------------------------------------------------------------------
diff --git a/README b/README
index ab764fd..20532c7 100644
--- a/README
+++ b/README
@@ -172,15 +172,15 @@ Install Prerequisites
          be set correctly and you will get compile errors.
 
     *3) The Adobe AIR integration kit for Windows can be downloaded from:
-           http://airdownload.adobe.com/air/win/download/4.0/AdobeAIRSDK.zip
+           http://airdownload.adobe.com/air/win/download/13.0/AdobeAIRSDK.zip
 
          The Adobe AIR integration kit for Mac can be downloaded from:
-            http://airdownload.adobe.com/air/mac/download/4.0/AdobeAIRSDK.tbz2
+            http://airdownload.adobe.com/air/mac/download/13.0/AdobeAIRSDK.tbz2
 
           The Adobe AIR integration kit for Linux can be downloaded from:
             http://airdownload.adobe.com/air/lin/download/2.6/AdobeAIRSDK.tbz2
 
-        This version of Apache Flex was certified for use with AIR 4.0, and
+        This version of Apache Flex was certified for use with AIR 13.0, and
         should be compatible with other versions of AIR newer than 3.1. However
         it hasn't been fully tested on AIR 3.2, 3.3, 3.5, 3.6 or 3.7.
 
@@ -229,6 +229,7 @@ Install Prerequisites
             http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_8.swc
             http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_9.swc
             http://download.macromedia.com/get/flashplayer/updaters/12/playerglobal12_0.swc
+            http://download.macromedia.com/get/flashplayer/updaters/13/playerglobal13_0.swc
 
         These can be used with Apache Flex but not all have not been fully
         tested.
@@ -294,7 +295,8 @@ Other Locale Support
         de_CH	en_AU	en_US	fr_CH	ja_JP	nl_NL	ru_RU	zh_TW
         de_DE	en_CA	es_ES	fr_FR	ko_KR	pt_BR	sv_SE
 
-    The Apache Flex SDK has only been tested for the en_US locale, however there    is unlikely to be any issues with a SDK compiled for another locales.
+    The Apache Flex SDK has only been tested for the en_US locale, however there
+    is unlikely to be any issues with a SDK compiled for another locales.
 
 Adobe Flash Player Version Support
 ----------------------------------


[3/4] git commit: [flex-sdk] [refs/heads/release4.12.0] - updated for FP/AIR 13 support

Posted by jm...@apache.org.
updated for FP/AIR 13 support


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/f5793941
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/f5793941
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/f5793941

Branch: refs/heads/release4.12.0
Commit: f5793941eaeba967194825777c0df63a2801bbf1
Parents: 56097fd
Author: Justin Mclean <jm...@apache.org>
Authored: Sat Apr 26 17:27:30 2014 +1000
Committer: Justin Mclean <jm...@apache.org>
Committed: Sat Apr 26 17:27:30 2014 +1000

----------------------------------------------------------------------
 ide/flashbuilder/makeApacheFlexForIDE.bat | 16 ++++++++--------
 ide/flashbuilder/makeApacheFlexForIDE.sh  | 10 +++++-----
 2 files changed, 13 insertions(+), 13 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/f5793941/ide/flashbuilder/makeApacheFlexForIDE.bat
----------------------------------------------------------------------
diff --git a/ide/flashbuilder/makeApacheFlexForIDE.bat b/ide/flashbuilder/makeApacheFlexForIDE.bat
index 05a115b..8b31a34 100755
--- a/ide/flashbuilder/makeApacheFlexForIDE.bat
+++ b/ide/flashbuilder/makeApacheFlexForIDE.bat
@@ -42,10 +42,10 @@ REM
 set APACHE_FLEX_BIN_DISTRO_DIR=..\..
 
 REM
-REM     Adobe AIR SDK Version 4.0
+REM     Adobe AIR SDK Version 13.0
 REM
 set ADOBE_AIR_SDK_WIN_FILE=AdobeAIRSDK.zip
-set ADOBE_AIR_SDK_WIN_URL=http://airdownload.adobe.com/air/win/download/4.0/%ADOBE_AIR_SDK_WIN_FILE%
+set ADOBE_AIR_SDK_WIN_URL=http://airdownload.adobe.com/air/win/download/13.0/%ADOBE_AIR_SDK_WIN_FILE%
 
 REM
 REM     Adobe Flash Player Version 11.1
@@ -53,9 +53,9 @@ REM
 set ADOBE_FB_GLOBALPLAYER_11_1_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
 
 REM
-REM     Adobe Flash Player Version 12.0
+REM     Adobe Flash Player Version 13.0
 REM
-set ADOBE_FB_GLOBALPLAYER_12_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal12_0.swc
+set ADOBE_FB_GLOBALPLAYER_13_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal13_0.swc
 
 :getDir
 if not [%1] == [] goto checkJar
@@ -124,13 +124,13 @@ cscript //B //nologo winUtil.vbs "%ADOBE_FB_GLOBALPLAYER_11_1_SWC_URL%" "%FB_GLO
 if %errorlevel% neq 0 goto errorExit
 
 REM
-REM     Download 12.0 playerglobal.swc
+REM     Download 13.0 playerglobal.swc
 REM
-set FB_GLOBALPLAYER_DIR=%FLEX_HOME%\frameworks\libs\player\12.0
+set FB_GLOBALPLAYER_DIR=%FLEX_HOME%\frameworks\libs\player\13.0
 if not exist "%FB_GLOBALPLAYER_DIR%" mkdir "%FB_GLOBALPLAYER_DIR%"
 
-echo Downloading Adobe Flash Player playerglobal.swc from "%ADOBE_FB_GLOBALPLAYER_12_0_SWC_URL%" to "%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
-cscript //B //nologo winUtil.vbs "%ADOBE_FB_GLOBALPLAYER_12_0_SWC_URL%" "%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
+echo Downloading Adobe Flash Player playerglobal.swc from "%ADOBE_FB_GLOBALPLAYER_13_0_SWC_URL%" to "%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
+cscript //B //nologo winUtil.vbs "%ADOBE_FB_GLOBALPLAYER_13_0_SWC_URL%" "%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
 if %errorlevel% neq 0 goto errorExit
 
 REM

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/f5793941/ide/flashbuilder/makeApacheFlexForIDE.sh
----------------------------------------------------------------------
diff --git a/README b/README
index 20532c7..f5c47d6 100644
--- a/README
+++ b/README
@@ -110,7 +110,7 @@ Install Prerequisites
 ---------------------
 
     Before building Flex you must install the following software and set the
-    corresponding environment variables using absolute file paths.  Relativei
+    corresponding environment variables using absolute file paths.  Relative
     file paths will result in build errors.
 
     The environment variables PLAYERGLOBAL_HOME, AIR_HOME, FLASHPLAYER_DEBUGGER,
@@ -322,7 +322,7 @@ Adobe Flash Player Version Support
     recompiled.  For example to compile against the latest version of the Adobe
     Flash Player set the value of playerglobal.version to be "12.0" like so:
 
-        playerglobal.version = 12.0
+        playerglobal.version = 13.0
 
     OR
 
@@ -348,6 +348,7 @@ Adobe Flash Player Version Support
     http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_8.swc
     http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_9.swc
     http://download.macromedia.com/get/flashplayer/updaters/12/playerglobal12_0.swc
+    http://download.macromedia.com/get/flashplayer/updaters/13/playerglobal13_0.swc
 
     Copy the target playerglobal.swc to the directory:
 
@@ -388,9 +389,11 @@ Adobe Flash Player Version Support
                          /playerglobal.swc
                     /12.0
                          /playerglobal.swc
+                    /13.0
+                         /playerglobal.swc
 
     Apache Flex has been tested with Adobe Flash Player 11.1, 11.5, 11.7, 11.8,
-    11.9 and 12.0 on Windows and Mac.
+    11.9, 12.0 nd 13.0 on Windows and Mac.
 
     Apache Flex has not been tested on Linux so some issue may exist in this
     release.
@@ -495,14 +498,14 @@ Using the Binary Distribution
 	This will create an Apache Flex 4.12.1 SDK that can be used with Flash
         Builder by copying the required files from the Adobe Flex 4.6 SDK.
 
-	To create an SDK for other IDE or if you want to use Adobe AIR 4.0
+	To create an SDK for other IDE or if you want to use Adobe AIR 13.0
         (rather than AIR 3.1 contained in Adobe Flex 4.6) run:
 
 		/ide/flashbuilder/makeApacheFlexForIDE.sh (on Mac and Linux)
 		/ide/flashbuilder/makeApacheFlexForIDE.bat (on Windows)
 
 	This will create an Apache Flex 4.12.1 SDK that can be used by an IDE by
-        downloading Adobe Flex 4.6 SDK and Adobe AIR 4.0.
+    downloading Adobe Flex 4.6 SDK and Adobe AIR 13.0.
 
 Building the Framework in a Binary Distribution
 -----------------------------------------------


[2/4] git commit: [flex-sdk] [refs/heads/release4.12.0] - added FP/AIR 13 support removed android skins as they have not been merged into this branch

Posted by jm...@apache.org.
added FP/AIR 13 support removed android skins as they have not been merged into this branch


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/56097fdd
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/56097fdd
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/56097fdd

Branch: refs/heads/release4.12.0
Commit: 56097fddcc9842d83bf05edce73db158c32fcf4d
Parents: 52043a7
Author: Justin Mclean <jm...@apache.org>
Authored: Sat Apr 26 17:26:51 2014 +1000
Committer: Justin Mclean <jm...@apache.org>
Committed: Sat Apr 26 17:26:51 2014 +1000

----------------------------------------------------------------------
 RELEASE_NOTES | 10 ++--------
 1 file changed, 2 insertions(+), 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/56097fdd/RELEASE_NOTES
----------------------------------------------------------------------
diff --git a/RELEASE_NOTES b/RELEASE_NOTES
index 0e5d552..1f98b05 100644
--- a/RELEASE_NOTES
+++ b/RELEASE_NOTES
@@ -32,23 +32,17 @@ Differences from Apache Flex 4.12 include:
 
 AIR and Flash Player support
 ------------------------------
-
+ - Support Flash Player 13.0
+ - Support for AIR 13.0
 
 SDK Changes
 -------------
-- New Android skins
 - Extended mobile media query support
 
-
-Build Changes
----------------
-
-
 Compiler Changes
 ------------------
 - Fix issue with 3rd party license components not working
 
-
 Bug Fixes
 ----------
  Below is a complete list of all the bug fixes that have been included since
diff --git a/ide/flashbuilder/makeApacheFlexForIDE.sh b/ide/flashbuilder/makeApacheFlexForIDE.sh
index 31966da..1ae9e5f 100755
--- a/ide/flashbuilder/makeApacheFlexForIDE.sh
+++ b/ide/flashbuilder/makeApacheFlexForIDE.sh
@@ -37,8 +37,8 @@
 # Apache Flex binary distribution
 APACHE_FLEX_BIN_DIR="$( cd $( dirname -- "$0" ) > /dev/null ; pwd )"/../..
 
-# Adobe AIR SDK Version 4.0
-ADOBE_AIR_SDK_MAC_URL=http://airdownload.adobe.com/air/mac/download/4.0/AdobeAIRSDK.tbz2
+# Adobe AIR SDK Version 13.0
+ADOBE_AIR_SDK_MAC_URL=http://airdownload.adobe.com/air/mac/download/13.0/AdobeAIRSDK.tbz2
 
 # Adobe Flash Player Version 11.1
 ADOBE_FLASHPLAYER_GLOBALPLAYER_11_1_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
@@ -104,9 +104,9 @@ mkdir -p "$FLEX_HOME/frameworks/libs/player/11.1"
 curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_11_1_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/11.1/playerglobal.swc"
 
 # download 11.9 playerglobal.swc
-echo "Downloading Adobe Flash Player playerglobal.swc from $ADOBE_FLASHPLAYER_GLOBALPLAYER_12_0_SWC_URL"
-mkdir -p "$FLEX_HOME/frameworks/libs/player/12.0"
-curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_12_0_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/12.0/playerglobal.swc"
+echo "Downloading Adobe Flash Player playerglobal.swc from $ADOBE_FLASHPLAYER_GLOBALPLAYER_13_0_SWC_URL"
+mkdir -p "$FLEX_HOME/frameworks/libs/player/13.0"
+curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_13_0_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/13.0/playerglobal.swc"
 
 # copy the config files formatted for Flash Builder to frameworks 
 echo "Installing the frameworks config files configured for use with Adobe Flash Builder"


[4/4] git commit: [flex-sdk] [refs/heads/release4.12.0] - fix few minor layout issues and updated to mention FP/AIR 13 support

Posted by jm...@apache.org.
fix few minor layout issues and updated to mention FP/AIR 13 support


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/d83446c7
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/d83446c7
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/d83446c7

Branch: refs/heads/release4.12.0
Commit: d83446c767aeee26cc5f7b1841bc533c4c40e160
Parents: f579394
Author: Justin Mclean <jm...@apache.org>
Authored: Sat Apr 26 17:30:06 2014 +1000
Committer: Justin Mclean <jm...@apache.org>
Committed: Sat Apr 26 17:30:06 2014 +1000

----------------------------------------------------------------------
 README | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d83446c7/README
----------------------------------------------------------------------